# Generated by ariadne-codegen on 2023-09-13 06:56
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import CheckoutStateFragment


class GetCheckoutState(BaseModel):
    checkout_state: "GetCheckoutStateCheckoutState" = Field(alias="checkoutState")


class GetCheckoutStateCheckoutState(CheckoutStateFragment):
    pass


GetCheckoutState.update_forward_refs()
GetCheckoutStateCheckoutState.update_forward_refs()



# Generated by ariadne-codegen on 2023-09-13 06:56
# Source: operations.graphql

from typing import List

from pydantic import Field

from .base_model import BaseModel
from .fragments import SubscriptionFragment


class GetActiveSubscriptions(BaseModel):
    get_active_subscriptions: List[
        "GetActiveSubscriptionsGetActiveSubscriptions"
    ] = Field(alias="getActiveSubscriptions")


class GetActiveSubscriptionsGetActiveSubscriptions(SubscriptionFragment):
    pass


GetActiveSubscriptions.update_forward_refs()
GetActiveSubscriptionsGetActiveSubscriptions.update_forward_refs()



# Generated by ariadne-codegen on 2023-09-13 06:56
# Source: operations.graphql

from typing import List

from .base_model import BaseModel
from .fragments import ProductFragment


class GetProducts(BaseModel):
    products: "GetProductsProducts"


class GetProductsProducts(BaseModel):
    edges: List["GetProductsProductsEdges"]


class GetProductsProductsEdges(BaseModel):
    node: "GetProductsProductsEdgesNode"


class GetProductsProductsEdgesNode(ProductFragment):
    pass


GetProducts.update_forward_refs()
GetProductsProducts.update_forward_refs()
GetProductsProductsEdges.update_forward_refs()
GetProductsProductsEdgesNode.update_forward_refs()



# Generated by ariadne-codegen on 2023-09-13 06:56
# Source: operations.graphql

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class ReportUsage(BaseModel):
    create_usage_measurement: "ReportUsageCreateUsageMeasurement" = Field(
        alias="createUsageMeasurement"
    )


class ReportUsageCreateUsageMeasurement(BaseModel):
    id: str
    current_usage: Optional[float] = Field(alias="currentUsage")
    next_reset_date: Optional[Any] = Field(alias="nextResetDate")
    timestamp: Any


ReportUsage.update_forward_refs()
ReportUsageCreateUsageMeasurement.update_forward_refs()



# Generated by ariadne-codegen on 2023-09-13 06:56
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimSubscriptionFragment


class UpdateSubscription(BaseModel):
    update_subscription: "UpdateSubscriptionUpdateSubscription" = Field(
        alias="updateSubscription"
    )


class UpdateSubscriptionUpdateSubscription(SlimSubscriptionFragment):
    pass


UpdateSubscription.update_forward_refs()
UpdateSubscriptionUpdateSubscription.update_forward_refs()



# Generated by ariadne-codegen on 2023-09-13 06:56
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimCustomerFragment


class ImportCustomer(BaseModel):
    import_customer: "ImportCustomerImportCustomer" = Field(alias="importCustomer")


class ImportCustomerImportCustomer(SlimCustomerFragment):
    pass


ImportCustomer.update_forward_refs()
ImportCustomerImportCustomer.update_forward_refs()
